from distutils.core import setup


setup(
    name='Demao',  #          
    version='1.0',  # version number
    description='Test Local Publish Module',  #
    author='SardorbekDeveloper22',  # Author
    author_email='sardorbekqozoqov2281@gmail.com',
    py_modules=['Demao.demo1', 'Demao.demo2'],  # To release the module
)